==> maverik-5.4.tar.gz: maverik-5.4/src/extras/VRML97/vrmlfields.h <==
/*
 GNU Maverik - a system for managing display and interaction in 
               Virtual Environment applications.
 Copyright (C) 1999-2000 Advanced Interfaces Group

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA


 The authors can be contacted via:
 www   - http://aig.cs.man.ac.uk
 email - maverik@aig.cs.man.ac.uk
 mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
         University of Manchester, Manchester, M13 9PL, UK
*/


#include "mavlib_cvcomp.h"

/******************************************************************
*
*	VRML library for C++
*
*	Copyright (C) Satoshi Konno 1996-1997
*
*	File:	vrmlfields.h
*
******************************************************************/

#ifndef _VRMLFIELD_H_
#define _VRMLFIELD_H_

#include "Field.h"
#include "SFBool.h"
#include "SFVec2f.h"
#include "SFVec3f.h"
#include "SFColor.h"
#include "SFRotation.h"
#include "SFMatrix.h"
#include "SFString.h"
#include "SFTime.h"
#include "SFInt32.h"
#include "SFFloat.h"
#include "SFImage.h"
#include "SFNode.h"

#include "MField.h"
#include "MFVec2f.h"
#include "MFVec3f.h"
#include "MFColor.h"
#include "MFRotation.h"
#include "MFInt32.h"
#include "MFTime.h"
#include "MFFloat.h"
#include "MFString.h"

#endif

==> maverik-6.1.tar.gz: maverik-6.1/src/extras/VRML97/vrmlfields.h <==
/*
 GNU Maverik - a system for managing display and interaction in 
               Virtual Environment applications.
 Copyright (C) 1999-2001 Advanced Interfaces Group

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA


 The authors can be contacted via:
 www   - http://aig.cs.man.ac.uk
 email - maverik@aig.cs.man.ac.uk
 mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
         University of Manchester, Manchester, M13 9PL, UK
*/


#include "mavlib_cvcomp.h"

/******************************************************************
*
*	VRML library for C++
*
*	Copyright (C) Satoshi Konno 1996-1997
*
*	File:	vrmlfields.h
*
******************************************************************/

#ifndef _VRMLFIELD_H_
#define _VRMLFIELD_H_

#include "Field.h"
#include "SFBool.h"
#include "SFVec2f.h"
#include "SFVec3f.h"
#include "SFColor.h"
#include "SFRotation.h"
#include "SFMatrix.h"
#include "SFString.h"
#include "SFTime.h"
#include "SFInt32.h"
#include "SFFloat.h"
#include "SFImage.h"
#include "SFNode.h"

#include "MField.h"
#include "MFVec2f.h"
#include "MFVec3f.h"
#include "MFColor.h"
#include "MFRotation.h"
#include "MFInt32.h"
#include "MFTime.h"
#include "MFFloat.h"
#include "MFString.h"

#endif
